@@ -33,7 +33,11 @@ class TestWPClient:
         result = wp_client._execute_wp("post list")
         
         assert result == "Success"
-        mock_ssh.execute.assert_called_once()
+        # Note: execute is called multiple times due to _verify_installation()
+        # We just verify the last call was our command
+        assert mock_ssh.execute.call_count >= 1
+        last_call = mock_ssh.execute.call_args[0][0]
+        assert "post list" in last_call
     
     def test_execute_wp_error(self, wp_client, mock_ssh):
         """Test WP-CLI execution with error"""
@@ -599,6 +603,51 @@ class TestWPClient:
         call_args = mock_ssh.execute.call_args[0][0]
         assert "core is-installed" in call_args
     
+    def test_wp_generic_command(self, wp_client, mock_ssh):
+        """Test generic wp() method with simple command"""
+        mock_ssh.execute.return_value = ("Success", "")
+        
+        result = wp_client.wp('cache', 'flush')
+        
+        assert result == "Success"
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "cache flush" in call_args
+    
+    def test_wp_with_kwargs(self, wp_client, mock_ssh):
+        """Test generic wp() method with keyword arguments"""
+        mock_ssh.execute.return_value = ('[{"ID": 1}]', "")
+        
+        result = wp_client.wp('post', 'list', status='publish', format='json')
+        
+        assert isinstance(result, list)
+        assert result[0]["ID"] == 1
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post list" in call_args
+        assert "--status='publish'" in call_args
+        assert "--format='json'" in call_args
+    
+    def test_wp_with_boolean_flag(self, wp_client, mock_ssh):
+        """Test generic wp() method with boolean flags"""
+        mock_ssh.execute.return_value = ("123", "")
+        
+        result = wp_client.wp('user', 'create', 'john', 'john@example.com', porcelain=True)
+        
+        assert result == "123"
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "user create john john@example.com" in call_args
+        assert "--porcelain" in call_args
+    
+    def test_wp_underscore_to_hyphen(self, wp_client, mock_ssh):
+        """Test generic wp() method converts underscores to hyphens"""
+        mock_ssh.execute.return_value = ("Result", "")
+        
+        result = wp_client.wp('search-replace', 'old', 'new', dry_run=True)
+        
+        assert result == "Result"
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "search-replace old new" in call_args
+        assert "--dry-run" in call_args
+    
     def test_search_replace(self, wp_client, mock_ssh):
         """Test search and replace"""
         mock_ssh.execute.return_value = ("Replaced 5 occurrences", "")
@@ -721,3 +770,188 @@ class TestWPClient:
         assert result == category
         call_args = mock_ssh.execute.call_args[0][0]
         assert "term get category 2" in call_args
+    
+    # Issue #1: Test author support in post creation
+    def test_create_post_with_author(self, wp_client, mock_ssh):
+        """Test creating post with author specified"""
+        mock_ssh.execute.return_value = ("123", "")
+        
+        result = wp_client.create_post(
+            title="Test Post",
+            content="Test content",
+            post_author=1
+        )
+        
+        assert result == 123
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post create" in call_args
+        assert "--post_author=" in call_args  # Author parameter is passed
+    
+    # Issue #2: Test post content update
+    def test_update_post_content_directly(self, wp_client, mock_ssh):
+        """Test updating post content directly"""
+        mock_ssh.execute.return_value = ("Success: Updated post 123", "")
+        
+        result = wp_client.update_post(123, post_content="New full content")
+        
+        assert result is True
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post update 123" in call_args
+        assert "--post_content=" in call_args
+    
+    # Issue #3: Test search in list_posts
+    def test_list_posts_with_search(self, wp_client, mock_ssh):
+        """Test listing posts with search parameter"""
+        import json
+        posts = [{"ID": 123, "post_title": "Pricing Strategies"}]
+        mock_ssh.execute.return_value = (json.dumps(posts), "")
+        
+        result = wp_client.list_posts(s="Pricing")
+        
+        assert result == posts
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post list" in call_args
+        assert "--s=" in call_args  # Search parameter is passed
+    
+    # v1.0.15: Test advanced create options
+    def test_create_post_with_excerpt(self, wp_client, mock_ssh):
+        """Test creating post with excerpt"""
+        mock_ssh.execute.return_value = ("123", "")
+        
+        result = wp_client.create_post(
+            post_title="Test Post",
+            post_content="Content",
+            post_excerpt="Short summary"
+        )
+        
+        assert result == 123
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post create" in call_args
+        assert "--post_excerpt=" in call_args
+    
+    def test_create_post_with_custom_date(self, wp_client, mock_ssh):
+        """Test creating post with custom date"""
+        mock_ssh.execute.return_value = ("123", "")
+        
+        result = wp_client.create_post(
+            post_title="Test Post",
+            post_content="Content",
+            post_date="2024-01-15 10:00:00"
+        )
+        
+        assert result == 123
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post create" in call_args
+        assert "--post_date=" in call_args
+    
+    def test_create_post_with_tags(self, wp_client, mock_ssh):
+        """Test creating post with tags"""
+        mock_ssh.execute.return_value = ("123", "")
+        
+        result = wp_client.create_post(
+            post_title="Test Post",
+            post_content="Content",
+            tags_input="python,wordpress"
+        )
+        
+        assert result == 123
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post create" in call_args
+        assert "--tags_input=" in call_args
+    
+    def test_create_post_with_meta(self, wp_client, mock_ssh):
+        """Test creating post with custom meta"""
+        mock_ssh.execute.return_value = ("123", "")
+        
+        result = wp_client.create_post(
+            post_title="Test Post",
+            post_content="Content",
+            meta_input='{"custom_field":"value","price":"99.99"}'
+        )
+        
+        assert result == 123
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post create" in call_args
+        assert "--meta_input=" in call_args
+    
+    def test_create_post_with_comment_status(self, wp_client, mock_ssh):
+        """Test creating post with comment status"""
+        mock_ssh.execute.return_value = ("123", "")
+        
+        result = wp_client.create_post(
+            post_title="Test Post",
+            post_content="Content",
+            comment_status="closed"
+        )
+        
+        assert result == 123
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post create" in call_args
+        assert "--comment_status=" in call_args
+    
+    # v1.0.16: Test advanced update options
+    def test_update_post_with_excerpt(self, wp_client, mock_ssh):
+        """Test updating post excerpt"""
+        mock_ssh.execute.return_value = ("Success: Updated post 123", "")
+        
+        result = wp_client.update_post(123, post_excerpt="New excerpt")
+        
+        assert result is True
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post update 123" in call_args
+        assert "--post_excerpt=" in call_args
+    
+    def test_update_post_with_author(self, wp_client, mock_ssh):
+        """Test updating post author"""
+        mock_ssh.execute.return_value = ("Success: Updated post 123", "")
+        
+        result = wp_client.update_post(123, post_author=2)
+        
+        assert result is True
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post update 123" in call_args
+        assert "--post_author=" in call_args
+    
+    def test_update_post_with_date(self, wp_client, mock_ssh):
+        """Test updating post date"""
+        mock_ssh.execute.return_value = ("Success: Updated post 123", "")
+        
+        result = wp_client.update_post(123, post_date="2024-01-15 10:00:00")
+        
+        assert result is True
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post update 123" in call_args
+        assert "--post_date=" in call_args
+    
+    def test_update_post_with_tags(self, wp_client, mock_ssh):
+        """Test updating post tags"""
+        mock_ssh.execute.return_value = ("Success: Updated post 123", "")
+        
+        result = wp_client.update_post(123, tags_input="python,ai")
+        
+        assert result is True
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post update 123" in call_args
+        assert "--tags_input=" in call_args
+    
+    def test_update_post_with_meta(self, wp_client, mock_ssh):
+        """Test updating post meta"""
+        mock_ssh.execute.return_value = ("Success: Updated post 123", "")
+        
+        result = wp_client.update_post(123, meta_input='{"views":"1000"}')
+        
+        assert result is True
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post update 123" in call_args
+        assert "--meta_input=" in call_args
+    
+    def test_update_post_with_comment_status(self, wp_client, mock_ssh):
+        """Test updating comment status"""
+        mock_ssh.execute.return_value = ("Success: Updated post 123", "")
+        
+        result = wp_client.update_post(123, comment_status="closed")
+        
+        assert result is True
+        call_args = mock_ssh.execute.call_args[0][0]
+        assert "post update 123" in call_args
+        assert "--comment_status=" in call_args
